# Master localization string file: $Id$
language_name: Ελληνικά
direction: ltr
more_options: Περισσότερες επιλογές
title_more_options: Show/Hide extra validation options
all: Όλα
normal_report: Κανονική αναφορά
most_important: Πιο σημαντικό
no_warnings: Καμία ειδοποίηση
profile: Προφίλ
no_special_profile: Κανένα ειδικό προφίλ
css1: Επίπεδο 1 CSS
css2: Επίπεδο 2 CSS
css21: Επίπεδο 2.1 CSS
css3: Επίπεδο 3 CSS
svg: SVG
svgbasic: Βασικό SVG
svgtiny: μικρό SVG
mobile: Κινητό
ATSC_TV_profile: Προφίλ ATSC TV
TV_profile: Προφίλ TV
medium: Μέσο
aural: ακουστικό
braille: σύστημα braille
embossed: ανάγλυφο
handheld: χειρός
print: εκτύπωση
projection: προβολή
screen: οθόνη
tty: TTY
tv: TV
presentation: παρουσίαση
type: Τύπος
no_special_type: Αυτόματο
html_doc: HTML
css_doc: CSS
check: Έλεγχος
W3C_CSS_validation_service: Υπηρεσία Ελέγχου Εγκυρότητας W3C CSS
check_CSS: Έλεγχος Cascading Style Sheets (CSS) και αρχείων (X)HTML με style sheets
by_URI: Με URI
by_file_upload: Με μεταφορά αρχείου
by_direct_input: Με άμεση εισαγωγή
validate_by_URI: Έλεγχος εγκυρότητας με URI
enter_uri: Εισάγετε το URI του αρχείου (HTML με CSS ή μόνο CSS) που θέλετε να ελέγξετε την εγκυρότητα
page_address: Διεύθυνση σελίδας για Έλεγχο Εγκυρότητας
address: Διεύθυνση
submit_uri: Υποβολή URI για έλεγχο εγκυρότητας
validate_by_file_upload: Έλεγχος εγκυρότητας με μεταφορά αρχείου
choose_document: Επιλέξτε το αρχείο που επιθυμείτε να ελέγξετε την εγκυρότητα
choose_local_file: Επιλέξτε ένα Τοπικό Αρχείο για Μεταφορά και Έλεγχο Εγκυρότητας
local_CSS_file: Τοπικό αρχείο CSS
submit_file: Υποβολή αρχείου για έλεγχο εγκυρότητας
validate_by_input: Έλεγχος εγκυρότητας με άμεση εισαγωγή
enter_CSS: Εισάγετε το CSS που θέλετε να ελέγξετε την εγκυρότητα
submit_input: Εισάγετε αρχείο για έλεγχο εγκυρότητας
note: Σημείωση
note_xhtml_valid: Εάν επιθυμείτε να ελέγξετε την εγκυρότητα ενός CSS style sheet που είναι ενσωματωμένο σε ένα αρχείο (X)HTML, πρέπει αρχικά να <a href="https://validator.w3.org/">ελέγξετε ότι είναι έγκυρο το αρχείο (X)HTML που χρησιμοποιείτε</a>
# End of variables added along with Index page template

W3C_validator_results: Αποτελέσματα Ελέγχου Εγκυρότητας W3C CSS για
# file_title: <!-- provided by the user -->
CSS_validation_service: Υπηρεσία Ελέγχου Εγκυρότητας CSS
jump_to: Μετάβαση σε
# errors_count: <!-- generated on the fly -->
errors: Σφάλματα
# warnings_count <!-- generated on the fly -->
warnings: Προειδοποιήσεις
validated_CSS: Έγκυρο CSS
congrats: Συγχαρητήρια! Δε βρέθηκε κανένα Σφάλμα.
# The sentence defined by doc_validates_before_link and doc_validates_after_link variables goes: \
# "This document validates as CSSXX!" where XX stands for the CSS version used \
# Since the content of the link about the CSS version is generated on the fly, \
# it is important to define what goes before the link and what goes afterwards in 2 separate \
# variables because the position of the link in the sentence varies in different languages
doc_validates_before_link: Έλεγχος εγκυρότητας αρχείου με την έκδοση 
doc_validates_after_link: !
no_errors_interoperable_msg: Για να δείξετε στους αναγνώστες σας ότι έχετε δημιουργήσει έναν ιστοσελίδα χωρίς λάθη, \
πρέπει να εμφανίσετε αυτό το εικονίδιο σε οποιαδήποτε σελίδα που είναι έγκυρη. Παρακάτω είναι ο κώδικας XHTML \
που πρέπει να χρησιμοποιήσετε για να προσθέσετε το εικονίδιο στην ιστοσελίδα σας:
valid_CSS: Έγκυρο CSS!
# <!-- close the img tag with > instead of /> if using HTML<= 4.01 -->
no_errors_close_tags_msg: κλείστε την ετικέτα img με &gt; αντί για /&gt; εάν χρησιμοποιείτε HTML &lt;= 4.01
no_errors_dl_local_msg: Εάν θέλετε, μπορείτε να κάνετε λήψη ενός αντιγράφου της εικόνας για να το έχετε στον τοπικό φάκελο \
του διακομιστή σας, και να τροποποιήσετε τον παραπάνω κώδικα XHTML έτσι ώστε να αναφέρεται στην τοπική εικόνα \
αντί γι' αυτή που βρίσκεται σε αυτόν τον διακομιστή.
no_errors_create_link_msg: Εάν επιθυμείτε να δημιουργήσετε ένα σύνδεσμο προς αυτή τη σελίδα (π.χ., σε αυτό το αποτέλεσμα \
ελέγχου εγκυρότητας) έτσι ώστε να είναι ευκολότερη ο μελλοντικός απενέλεγχος εγκυρότητας της σελίδας ή για να επιτρέψετε \
σε άλλους να ελέγχουν την εγκυρότητα της σελίδας, το URI είναι:
no_errors_forHTML_only_msg: μόνο για αρχεία HTML/XML
no_errors_bookmark_msg: Ή μπορείτε να προσθέσετε την τρέχουσα σελίδα στα αγαπημένα σας ή στη hotlist.
note_valide_html: Για να λειτουργεί όπως προτείνεται, το CSS style sheet χρειάζεται ένα σωστό δέντρο συντακτικής ανάλυσης. Αυτό σημαίνει ότι πρέπει να χρησιμοποιείτε ένα <a href="https://validator.w3.org/">έγκυρο HTML</a>.
top: Πάνω
# hook_html_validator <!-- generated on the fly -->
not-css1-style: /* ΠΡΟΣΟΧΗ ! Δεν πρόκεται για ιδιότητα CSS1 ! */
errors_sorry_msg: Συγνώμη! Βρέθηκαν τα παρακάτω σφάλματα
# errors_list: <!-- generated on the fly -->
# warnings_list: <!-- generated on the fly -->
# rules_count: <!-- generated on the fly -->
valid_CSS_info: Πληροφορίες έγκυρου CSS
# charset: <!-- generated on the fly -->
# rules_list: <!-- generated on the fly -->
CSS_not_found: Δε βρέθηκε style sheet
home: Αρχική Σελίδα
about: Σχετικά
doc: Εγχειρίδια Χρήσης
dl: Λήψη Αρχείων
feedback: Η Γνώμη Σας
credits: Ευχαριστίες
home_title: Αρχική Σελίδα της W3C CSS Υπηρεσίας Ελέγχου Εγκυρότητας
about_title: Σχετικά με την υπηρεσία
doc_title: Εγχειρίδια Χρήσης για την W3C CSS Υπηρεσία Ελέγχου Εγκυρότητας
dl_title: Λήψη και Εγκατάσταση του Ελεγκτή Εγκυρότητας CSS
feedback_title: Πως να πείτε τη γνώμη σας γι' αυτή την υπηρεσία
credits_title: Ευχαριστίες
W3C_quality_msg: Η Δραστηριότητα Διασφάλισης Ποιότητας της W3C, σας παρέχει δωρεάν ποιοτικά εργαλεία στο διαδίκτυο και περισσότερα
learn_more_msg: Μάθετε περισσότερα για τα Cascading Style Sheets
support: Υποστηρίξτε το εργαλείο, γίνετε
supporter: Υποστηρικτής της W3C
# End of variables added along with Velocity

# Defines your own error and warning message here
content-type: text/html; charset=utf-8
content-language: en
output-encoding-name: utf-8

# You can change the level warning like this (example) :
# warning.redefinition.level: 5
#  level is an integer between 0 and 9 (all others values are ignored)
warning.redefinition: Επαναπροσδιορισμός του \u201C%s\u201D

# used by xml parser 
warning.style-inside-comment: Μη βάζετε κανόνες στιλ μέσα σε σχόλια στο αρχείο HTML γιατί θα αφαιρεθούν από το λογισμικό

# used by org.w3c.css.properties.Css1Style
warning.same-colors: Ίδιο χρώμα για \u201C%s\u201D και \u201C%s\u201D
warning.no-color: Δεν έχετε ορισμό για χρώμα (ή το χρώμα είναι ορισμένο στο διάφανο) αλλά έχετε ορίσει ένα διάφανο φόντο. Βεβαιωθείτε ότι η διαδοχή των χρωμάτων κάνει ευανάγνωστα τα γράμματα.
warning.no-background-color: Δεν έχετε ορισμό για φόντο (ή το χρώμα είναι ορισμένο στο διάφανο) αλλά έχετε ορίσει ένα χρώμα. Βεβαιωθείτε ότι η διαδοχή των χρωμάτων κάνει ευανάγνωστα τα γράμματα.
#warning.color.mixed-capitalization is now obsolete
#warning.color.mixed-capitalization: Αν η ονομασία των χρωμάτων δεν κάνει διάκριση πεζών κεφαλαίων, προτείνεται η χρήση κεφαλαίων για να είναι πιο ευανάγνωστα τα ονόματα: \u201C%s\u201D
warning.no-generic-family: \u201C%s\u201D: Προτείνεται η χρήση μίας γενικής οικογένειας γραμματοσειράς ως τελευταία εναλλακτική
warning.with-space: Οι οικογένειες γραμματοσειρών που περιέχουν κενά, πρέπει να εισάγονται μέσα σε εισαγωγικά. Εάν δεν βάζετε εισαγωγικά, οποιοδήποτε κενοί  \
χαρακτήρες πριν και μετά το όνομα αγνοούνται και οποιαδήποτε συνεχόμενη σειρά κενών χαρακτήρων \
μετατρέπεται σε ένα μόνο κενό. 
warning.no-padding: Προτείνεται να έχετε μία περιοχή με γέμισμα φόντου
warning.same-colors2: Ίδια χρώματα για χρώμα και για χρώμα φόντου σε δύο περιεχόμενα \u201C%s\u201D και \u201C%s\u201D
warning.relative-absolute: Έχετε απόλυτα και αναφορικά μήκοι στο \u201C%s\u201D. Δεν πρόκειται για ένα στιβαρό style sheet.
# used by org.w3c.css.properties.CssSelectors
warning.unknown-html: Το \u201C%s\u201D δεν αποτελεί ένα Στοιχείο HTML
warning.html-inside: Το στοιχείο HTML δεν μπορεί να είναι μέσα σε άνα άλλο στοιχείο
warning.body-inside: Το στοιχείο BODY δεν μπορεί να είναι μέσα σε άνα άλλο στοιχείο εκτός από το HTML
warning.pseudo-classes: Η ψευδοκλάση Anchor \u201C%s\u201D δεν έχει κανένα αποτέλεσμα σε στοιχεία άλλα εκτός από τα 'A'

# not used by org.w3c.css.properties.CssSelectors for the moment
warning.noinside: Το \u201C%s\u201D δεν μπορεί να βρίσκεται μέσα σε ένα εσωτερικό στοιχείο
warning.withblock: Προσοχή. Τα ψευδό-στοιχεία μπορούν να είναι συνημμένα μόνο σε ένα στοιχείο block-level
warning.block-level: Η ιδιότητα αυτή εφαρμόζεται σε στοιχεία block-level.

# used by org.w3c.css.parser.Frame
warning.no-declaration: Καμία διακήρυξη για τον κανόνα

# used by org.w3c.css.parser.CssFouffa
warning.unsupported-import: Τα εισαγώμενα style sheet δεν ελέγχονται στην κατάσταση άμεσης εισαγωγής και μεταφοράς αρχείου

# used by org.w3c.css.values.CssColor
warning.out-of-range: Το \u201C%s\u201D είναι εκτός εύρους
error.invalid-color: Μη έγκυρη λειτουργία RGB

warning.marker: Η ιδιότητα marker-offset εφαρμόζεται σε στοιχεία με 'display: marker'

# used by org.w3c.css.properties.ACssStyle
warning.relative: Η χρήση αναφορικών κανόνων παρέχει περισσότερο στιβαρά stylesheet στην ιδιότητα \u201C%s\u201D

# used by org.w3c.css.css.StyleSheetParser and org.w3c.css.css.StyleSheetXMLParser
error.at-rule: Συγνώμη, ο κανόνας \u201C%s\u201D δεν εφαρμόζεται.
warning.at-rule: Συγνώμη, ο κανόνας \u201C%s\u201D δεν εφαρμόζεται.

# used by all properties and values
error.operator: Το \u201C%s\u201D είναι ένας λανθασμένος τελεστής
error.negative-value: Οι αρνητικές τιμές \u201C%s\u201D δεν επιτρέπονται
error.few-value: πολύ λίγες τιμές για την ιδιότητα \u201C%s\u201D

# be careful here, values comes first
# You can't write something like this : For the color, blue is an incorrect value
error.value: Το \u201C%s\u201D δεν είναι μία τιμή \u201C%s\u201D

#used by org.w3c.css.properties3.CssToggleGroup
error.groupname: Το \u201C%s\u201D δεν αποτελεί μία σωστή ονομασία ομάδας. Χρησιμοποιήστε έναν έγκυρο προσδιορισμό

#used by org.w3c.css.properties3.CssGroupReset
error.nogroup: Το \u201C%s\u201D δεν έχει οριστεί από την ιδιότητα toggle-group property

#used by org.w3c.css.properties3.CssGlyphOrVert
error.anglevalue: Η τιμή πρέπει να κυμαίνεται ανάμεσα στο -360 και 360 και να μπορεί να διαιρείται με το 90

#used by org.w3c.css.properties3.CssTextKashidaSpace
error.percentage: αναμένεται ποσοστιαία τιμή

#used by org.w3c.css.properties.CssTextAlign
warning.xsl: η τιμή \u201C%s\u201D εφαρμόζεται μόνο στο XSL

#used by org.w3c.css.parser.analyzer.CssParser
warning.medialist: το μέσο πρέπει να ξεκινάει με 'media :' \u201C%s\u201D
error.nocomb: Ο συνδυασμός \u201C%s\u201D ανάμεσα σε επιλογείς δεν επιτρέπεται στο προφίλ ή έκδοση

#used by org.w3c.css.properties.CssDirection
warning.direction: αντί να χρησιμοποιήσετε το 'direction' για στοιχεία block-level χρησιμοποιήστε τη νέα ιδιότητα του CSS3 'writing-mode'

# used by org.w3c.css.properties.CssTextDecoration
error.same-value: το \u201C%s\u201D εμφανίζεται δύο φορές

error.generic-family.quote: Οι γενικές ονομασίες οικογενειών γραμματοσειρών είναι δεσμευμένες λέξεις και επομένως δεν πρέπει να μπαίνουν σε εισαγωγικά.

# used by org.w3c.css.properties.CssClip
error.shape: Invalid shape definition rect(<top>,<right>,<bottom>,<left>)
error.shape-separator: Μη έγκυρος διαχωριστής στον προσδιορισμό μορφής. Πρέπει να είναι κόμμα.

# used by org.w3c.css.properties.CssContent
error.attr: Μη έγκυρος ορισμός του χαρακτηριστικού attr(X)
error.function: Μη έγκυρος ορισμός του προσδιορισμού
error.counter: Μη έγκυρος ορισμός του προσδιορισμού counter(<identifier>[,<list-style-type>]?)
error.counters: Μη έγκυρος ορισμός του προσδιορισμού counters(<identifier>,<string>[,<list-style-type>]?)

# used by org.w3c.css.font.Src
error.format: Μη έγκυρος προσδιορισμός μορφοποίησης format(<string>[,<string>]*)
error.local: Μη έγκυρος προσδιορισμός μορφοποίησης local(<string>|<ident>+)

# used by org.w3c.css.values.CssAngle, org.w3c.css.values.CssFrequency, org.w3c.css.values.CssTime, org.w3c.css.values.CssLength
error.unit: το \u201C%s\u201D αποτελεί μία λανθασμένη μονάδα

# used by org.w3c.css.aural.ACssAzimuth
error.degree: Η θέση πρέπει να περιγράφεται σε μοίρες.

# used by org.w3c.css.aural.ACssElevation
error.elevation.range: Περιγράφει την ανύψωση μίας γωνίας, ανάμεσα σε '-90deg' και '90deg'.

# used by org.w3c.css.aural.ACssPitchRange
error.range: Η τιμή είναι εκτός εύρους. Η τιμή πρέπει να είναι ανάμεσα σε '0' και '100'.

# used by org.w3c.css.properties.CssTextShadow
error.two-lengths: Η μετατόπιση σκιάς (shadow offset) να περιγράφεται με δύο τιμές <length> (μπορεί να προσδιοριστεί προαιρετικά μία ακτίνα blur μετά την μετατόπιση σκιάς (shadow offset).)

error.integer: Ο αριθμός αυτός πρέπει να είναι ακέραιος.
error.comma: Λείπει το κόμμα.

# used by org.w3c.css.values.CssPercentage
error.percent: Το \u201C%s\u201D αποτελεί ένα λανθασμένο ποσοστό

# used by org.w3c.css.values.CssString
error.string: Το \u201C%s\u201D αποτελεί μία λανθασμένη συμβολοσειρά

# used by org.w3c.css.values.CssURL
error.url: Το \u201C%s\u201D αποτελεί ένα λανθασμένο URL

# used by org.w3c.css.values.CssColor
error.rgb: Το \u201C%s\u201D δεν αποτελεί ένα έγκυρο χρώμα 3 ή 6 δεκαεξαδικών αριθμών
error.angle: Το \u201C%s\u201D δεν αποτελεί μία έγκυρη γωνία. Η τιμή πρέπει να είναι ανάμεσα στο 0 και 360

# used by org.w3c.css.values.CssNumber
error.zero: μόνο το 0 μπορεί να είναι ένα \u201C%s\u201D. Πρέπει να τοποθετήσετε μία μονάδα μετά τον αριθμό
warning.zero: μόνο το 0 μπορεί να είναι ένα \u201C%s\u201D. Πρέπει να τοποθετήσετε μία μονάδα μετά τον αριθμό

# used by org.w3c.css.parser.CssPropertyFactory
error.noexistence-at-all: Η ιδιότητα \u201C%s\u201D δεν υπάρχει
error.noexistence-media: Η ιδιότητα \u201C%s\u201D δεν υπάρχει για το μέσο \u201C%s\u201D
error.noexistence: Η ιδιότητα \u201C%s\u201D δεν υπάρχει στο \u201C%s\u201D αλλά υπάρχει στο \u201C%s\u201D
warning.noexistence: Η ιδιότητα \u201C%s\u201D δεν υπάρχει στο \u201C%s\u201D αλλά υπάρχει στο \u201C%s\u201D
warning.noexistence-media: Η ιδιότητα \u201C%s\u201D δεν υπάρχει για το μέσο \u201C%s\u201D
warning.notforusermedium : Η ιδιότητα \u201C%s\u201D δεν υπάρχει γι' αυτό το μέσο
warning.noothermedium : Οι ιδιότητες για άλλα μέσα μπορεί να μη λειτουργούν για το μέσο
# used by org.w3c.css.parser.AtRule*
error.noatruleyet: Άλλοι κανόνες @rules από το @import δεν υποστηρίζονται από το CSS1 \u201C%s\u201D
# used by org.w3c.css.parser.analyzer.CssParser
error.notforcss1: Η τιμή \u201C%s\u201D δεν υπάρχει για το CSS1
warning.pseudo: Άγνωστο ψευδο-στοιχείο ή ψευδο-κλάση \u201C%s\u201D στο προεπιλεγμένο προφίλ (\u201C%s\u201D)
warning.nocomb: Συνδυασμός \u201C%s\u201D ανάμεσα σε επιλεγείς δεν επιτρέπεται σε αυτό το προφίλ (\u201C%s\u201D)
warning.charsetspecial: Το προφίλ αυτό έχει μία πολύ συγκεκριμένη σύνταξη για το @charset: \
το @charset ακολουθείται από ένα κενό, το οποίο ακολουθείται από το όνομα της κωδικοποίησης \
μέσα σε εισαγωγικά, και ακολουθείται αμέσως από semicolon.
warning.notversion: Το \u201C%s\u201D δεν μπορεί να χρησιμοποιηθεί με αυτή την έκδοση του CSS : \u201C%s\u201D

# used by org.w3c.css.parser.CssFouffa
error.unrecognize: Πάρα πολλές τιμές ή οι τιμές δεν αναγνωρίζονται

# used by org.w3c.css.parser.CssFouffa
generator.unrecognize: Σφάλμα Ανάλυσης
generator.dontmixhtml: Σφάλμα Ανάλυσης. Τα Style sheet δεν πρέπει να περιλαμβάνουν συντακτικό HTML.  

# used by org.w3c.css.css.StyleSheetGeneratorHTML2
error.unknown: Άγνωστο σφάλμα

# used by org.w3c.css.parser.CssSelectors
error.pseudo-element: Το ψευδο-στοιχείο: \u201C%s\u201D δεν μπορεί να εμφανίζεται εδώ στο κείμενο \u201C%s\u201D
error.pseudo-class: η ψευδο-κλάση .\u201C%s\u201D δεν μπορεί να εμφανίζεται στο κείμενο HTML \u201C%s\u201D
error.pseudo: Άγνωστο ψευδο-στοιχείο ή ψευδο-κλάση \u201C%s\u201D
error.id: Ο επιλογέας ID #\u201C%s\u201D δεν είναι έγκυρος ! Μόνο ένας επιλογέας ID μπορεί να προσδιορίζεται σε έναν απλό επιλογέα: \u201C%s\u201D.
error.space: Εάν χρησιμοποιείται ο επιλογέας χαρακτηριστικού ~=, tη λέξη στην τιμή \u201C%s\u201D δεν πρέπει να περιέχει κενά.
error.todo : Συγνώμη το χαρακτηριστικό \u201C%s\u201D δεν υλοποιείται ακόμη.
error.incompatible: τα \u201C%s\u201D και \u201C%s\u201D δεν είναι συμβατά
warning.incompatible: τα \u201C%s\u201D και \u201C%s\u201D δεν είναι συμβατά
error.notformobile: το \u201C%s\u201D δεν μπορεί να χρησιμοποιηθεί με κινητό προφίλ
error.notforatsc: το \u201C%s\u201D δεν μπορεί να χρησιμοποιηθεί με προφίλ ATSC
error.notfortv: το \u201C%s\u201D δεν μπορεί να χρησιμοποιηθεί με προφίλ TV
error.notversion: to \u201C%s\u201D δεν μπορεί να χρησιμοποιηθεί με αυτή την έκδοση του CSS : \u201C%s\u201D

error.media: μη αναγνωρίσιμο μέσο \u201C%s\u201D 
error.page: μη αναγνωρίσιμο σελίδας με ψευδώνυμο \u201C%s\u201D

error.unrecognized.link: Μη αναγνωρίσιμο στοιχείο σύνδεσμου ή xml-stylesheet PI.

# used by StyleSheetGeneratorHTML
generator.context: Κείμενο
generator.request: Προκλήθηκε σφάλμα κατά την έξοδο του αποτελέσματος του style sheet. \
Παρακαλούμε διορθώστε το αίτημα σας ή στείλτε μήνυμα στο plh@w3.org.
generator.unrecognized: Μη αναγνωρίσιμο
generator.invalid-number: Μη έγκυρος αριθμός
generator.property: Σφάλμα τιμής
generator.line: Γραμμή
generator.not-found: Δε βρέθηκε αρχείο

generator.doc-html:   <!-- removed this confusing message olivier 2006-12-14 -->
generator.doc:  <!-- removed this confusing message olivier 2006-12-14 -->


# used by the parser
parser.semi-colon: προσπάθεια εύρεσης ενός semi-colon πριν την ονομασία ιδιότητας. Προσθέστε το

parser.unknown-dimension: Άγνωστη διάσταση

parser.old_class: Στο CSS1, η ονομασία κλάσης πρέπει να ξεκινάει με ένα ψηφίο (".55ft"), \
εκτός και εάν ήταν διάσταση (".55in"). Στο CSS2, τέτοιες κλάσεις πρέπει να αναλύονται ως \
άγνωστες διαστάσεις (για να επιτρέπουν τη μελλοντική πρόσθεση νέων μονάδων) \
Για να γίνει το ".\u201C%s\u201D" μία έγκυρη κλάση, το CSS2 απαιτεί τη διαφυγή του πρώτου ψηφίου ".\3\u201C%s\u201D"

parser.old_id: Στο CSS1, η ονομασία id πρέπει να ξεκινάει με ένα ψηφίο ("#55ft"), \
εκτός και εάν ήταν διάσταση ("#55in"). Στο CSS2, τέτοια id πρέπει να αναλύονται ως \
άγνωστες διαστάσεις (για να επιτρέπουν τη μελλοντική πρόσθεση νέων μονάδων)

parser.class_dim: Στο CSS1, η ονομασία κλάσης μπορεί να ξεκινάει με ένα ψηφίο (".55ft"), \
εκτός και εάν είναι διάστασηn (".55in").

parser.id_dim: Στο CSS1, η ονομασία id μπορεί να ξεκινάει με ένα ψηφίο ("#55ft"), \
εκτός και εάν είναι διάσταση ("#55in").

parser.charset: Ο κανόνας @charset μπορεί να προκύπτει στην αρχή του κάθε style \
sheet. Ελέγξτε ότι δεν υπάρχουν κενά πριν από τον κανόνα.

parser.charsetspecial: Το προφίλ αυτό έχει ένα πολύ συγκεκριμένο συντακτικό για το @charset: \
το @charset ακολουθείται από ένα κενό, το οποίο ακολουθείται από το όνομα της κωδικοποίησης \
μέσα σε εισαγωγικά, και ακολουθείται αμέσως από semicolon.

warning.old_id: Στο CSS1, η ονομασία id μπορεί να ξεκινάει με ένα ψηφίο ("#55ft"), \
εκτός και εάν είναι διάσταση ("#55in"). Στο CSS2, τέτοια id πρέπει να αναλύονται ως \
άγνωστες διαστάσεις (για να επιτρέπουν τη μελλοντική πρόσθεση νέων μονάδων)

warning.old_class:  Στο CSS1, η ονομασία κλάσης μπορεί να ξεκινάει με ένα ψηφίο ("#55ft"), \
εκτός και εάν είναι διάσταση ("#55in"). Στο CSS2, τέτοια id πρέπει να αναλύονται ως \
άγνωστες διαστάσεις (για να επιτρέπουν τη μελλοντική πρόσθεση νέων μονάδων).

# used by the servlet
servlet.invalid-request: Στείλατε ένα μη έγκυρο αίτημα.
servlet.process: Το αντικείμενο δεν επεξεργάζεται

warning.atsc: Το \u201C%s\u201D μπορεί να μην υποστηρίζεται από το μέσο atsc-tv
error.onlyATSC: \u201C%s\u201D η λειτουργία αυτή υποστηρίζεται μόνο για το μέσο atsc-tv

warning.otherprofile: η ιδιότητα \u201C%s\u201D δεν υπάρχει σ' αυτό το προφίλ, αλλά μπορεί να ελεγχθεί η εγκυρότητα του με βάση ένα άλλο προφίλ

warning.float-no-width: Στο (x)HTML+CSS, τα πλωτά στοιχεία (floated elements) χρειάζεται να έχουν ορισμένο πλάτος. Μόνο τα στοιχεία με φυσικό πλάτος δεν επηρεάζονται (html, img, input, textarea, select, ή object)

parser.charsetcss1: οι κανόνες @charset δεν μπορούν να χρησιμοποιηθούν στο CSS1
parser.attrcss1: Οι επιλογείς χαρακτηριστικών δεν είναι έγκυροι στο CSS1
